pub struct RocksDBStore { /* private fields */ }Expand description
Persistent storage with RocksDB.
Implementations
Sourceimpl RocksDBStore
impl RocksDBStore
Sourceimpl RocksDBStore
impl RocksDBStore
Sourcepub fn open_tables_read_write(
path: PathBuf,
metric_conf: MetricConf,
global_db_options_override: Option<Options>,
tables_db_options_override: Option<DBMapTableConfigMap>,
) -> Self
pub fn open_tables_read_write( path: PathBuf, metric_conf: MetricConf, global_db_options_override: Option<Options>, tables_db_options_override: Option<DBMapTableConfigMap>, ) -> Self
Opens a set of tables in read-write mode
Only one process is allowed to do this at a time
global_db_options_override apply to the whole DB
tables_db_options_override apply to each table. If None, the attributes from default_options_override_fn are used if any
pub fn open_tables_read_write_with_deprecation_option( path: PathBuf, metric_conf: MetricConf, global_db_options_override: Option<Options>, tables_db_options_override: Option<DBMapTableConfigMap>, remove_deprecated_tables: bool, ) -> Self
Sourcepub fn get_read_only_handle(
primary_path: PathBuf,
with_secondary_path: Option<PathBuf>,
global_db_options_override: Option<Options>,
metric_conf: MetricConf,
) -> RocksDBStoreReadOnly
pub fn get_read_only_handle( primary_path: PathBuf, with_secondary_path: Option<PathBuf>, global_db_options_override: Option<Options>, metric_conf: MetricConf, ) -> RocksDBStoreReadOnly
This opens the DB in read only mode and returns a struct which exposes debug features